#pragma once
#include "widgets/ut_shapeswidget.h" //放前面
#include "ut_main_window.h"
#include "utils/ut_pixmergethread.h"
#include "utils/ut_scrollScreenshot.h"
#include "utils/ut_audioutils.h"
#include "utils/ut_baseutils.h"
#include "utils/ut_configsettings.h"
//#include "utils/ut_desktopinfo.h"
#include "utils/ut_screengrabber.h"
#include "utils/ut_shortcut.h"
#include "utils/ut_tempfile.h"
#include "utils/ut_utils_other.h"
#include "utils/ut_calculaterect.h"
#include "widgets/ut_keybuttonwidget.h"
#include "widgets/ut_colortoolwidget.h"
#include "widgets/ut_maintoolwidget.h"
#include "widgets/ut_zoomIndicator.h"
#include "menucontroller/ut_menucontroller.h"
#include "dbusinterface/ut_dbusnotify.h"
#include "dbusinterface/ut_ocrinterface.h"
#include "ut_RecorderRegionShow.h"
#include "ut_countdown_tooltip.h"
#include "ut_settings.h"
#include "ut_show_buttons.h"
#include "ut_utils.h"
#include "ut_button_feedback.h"
#include "ut_record_process.h"
//#include "ut_screenshot.h"
#include "utils/ut_voiceVolumeWatcher.h"
#include "utils/ut_WaylandScrollMonitor.h"
//#include "widgets/ut_shapeswidget.h"
#include "widgets/ut_toptips.h"
#include "widgets/ut_camerawidget.h"
#include "widgets/ut_tooltips.h"
#include "widgets/ut_textedit.h"
#include "widgets/ut_shottoolwidget.h"
#include "widgets/ut_subtoolwidget.h"
#include "widgets/ut_hoverfilter.h"
#include "widgets/ut_hintfilter.h"
#include "widgets/ut_hovershadowfilter.h"
#include "widgets/ut_hintfilterprivate.h"
#include "widgets/ut_toolbutton.h"
#include "widgets/ut_toolbarwidget.h"
//#include "widgets/ut_toolbar.h"
#include "widgets/ut_sidebar.h"
#include "widgets/ut_sidebarwidget.h"
#include "widgets/ut_scrollshottip.h"
#include "waylandrecord/ut_avinputstream.h"
#include "waylandrecord/ut_avoutputstream.h"
#include "waylandrecord/ut_recordadmin.h"
#include "waylandrecord/ut_waylandintegration.h"
#include "waylandrecord/ut_waylandintegration_p.h"
#include "waylandrecord/ut_writeframethread.h"

